Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(115)

Unified Diff: chromeos/dbus/shill_client_helper.h

Issue 10915106: Renaming instances of "flimflam" with "shill", now that we're only (Closed) Base URL: http://git.chromium.org/chromium/src.git@master
Patch Set: Upload after merge Created 8 years, 3 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « chromeos/dbus/mock_shill_service_client.cc ('k') | chromeos/dbus/shill_client_helper.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: chromeos/dbus/shill_client_helper.h
diff --git a/chromeos/dbus/flimflam_client_helper.h b/chromeos/dbus/shill_client_helper.h
similarity index 92%
rename from chromeos/dbus/flimflam_client_helper.h
rename to chromeos/dbus/shill_client_helper.h
index c2c0c23f04951e9f86c35feec3158e0339da0ed2..84534e090c8acafb4e3babdb4ef4e882cf0818e2 100644
--- a/chromeos/dbus/flimflam_client_helper.h
+++ b/chromeos/dbus/shill_client_helper.h
@@ -2,8 +2,8 @@
// Use of this source code is governed by a BSD-style license that can be
// found in the LICENSE file.
-#ifndef CHROMEOS_DBUS_FLIMFLAM_CLIENT_HELPER_H_
-#define CHROMEOS_DBUS_FLIMFLAM_CLIENT_HELPER_H_
+#ifndef CHROMEOS_DBUS_SHILL_CLIENT_HELPER_H_
+#define CHROMEOS_DBUS_SHILL_CLIENT_HELPER_H_
#include <string>
@@ -35,8 +35,8 @@ class Signal;
namespace chromeos {
-// A class to help implement Flimflam clients.
-class FlimflamClientHelper {
+// A class to help implement Shill clients.
+class ShillClientHelper {
public:
// A callback to handle PropertyChanged signals.
typedef base::Callback<void(const std::string& name,
@@ -56,9 +56,9 @@ class FlimflamClientHelper {
typedef base::Callback<void(const std::string& error_name,
const std::string& error_message)> ErrorCallback;
- FlimflamClientHelper(dbus::Bus* bus, dbus::ObjectProxy* proxy);
+ ShillClientHelper(dbus::Bus* bus, dbus::ObjectProxy* proxy);
- virtual ~FlimflamClientHelper();
+ virtual ~ShillClientHelper();
// Sets PropertyChanged signal handler.
void SetPropertyChangedHandler(const PropertyChangedHandler& handler);
@@ -153,11 +153,11 @@ class FlimflamClientHelper {
// Note: This should remain the last member so it'll be destroyed and
// invalidate its weak pointers before any other members are destroyed.
- base::WeakPtrFactory<FlimflamClientHelper> weak_ptr_factory_;
+ base::WeakPtrFactory<ShillClientHelper> weak_ptr_factory_;
- DISALLOW_COPY_AND_ASSIGN(FlimflamClientHelper);
+ DISALLOW_COPY_AND_ASSIGN(ShillClientHelper);
};
} // namespace chromeos
-#endif // CHROMEOS_DBUS_FLIMFLAM_CLIENT_HELPER_H_
+#endif // CHROMEOS_DBUS_SHILL_CLIENT_HELPER_H_
« no previous file with comments | « chromeos/dbus/mock_shill_service_client.cc ('k') | chromeos/dbus/shill_client_helper.cc » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698